// OpenVideoFileView.cpp : implementation of the COpenVideoFileView class
//

#include "stdafx.h"
#include "OpenVideoFile.h"

#include "OpenVideoFileDoc.h"
#include "OpenVideoFileDoc.h"
#include "OpenVideoFileView.h"

#include "MemoryDC.h"
#include "VideoManager.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

/********************************************************************************/
IMPLEMENT_DYNCREATE(COpenVideoFileView, CView)	// COpenVideoFileView
/********************************************************************************/
BEGIN_MESSAGE_MAP(COpenVideoFileView, CView)
END_MESSAGE_MAP()
/********************************************************************************/
COpenVideoFileView::COpenVideoFileView()	// COpenVideoFileView construction/destruction
{
	_memoryDC = NULL;

	_gdiplusToken = 0;

	_viewSize.SetSize(0, 0);

	Gdiplus::GdiplusStartupInput gdiplusStartupInput;
	Gdiplus::GdiplusStartup(&_gdiplusToken, &gdiplusStartupInput, NULL);
}

COpenVideoFileView::~COpenVideoFileView()
{
	GdiplusShutdown(_gdiplusToken);

	COpenVideoFileDoc* pDoc = GetDocument();
	pDoc->StopVideoThread();

	SAFE_DELETE(_memoryDC);
}
/********************************************************************************/
void COpenVideoFileView::DrawNextFrameDC(CDC* pDC)
{
	CRect clipBoxRect,oldClipBoxRect;

	clipBoxRect.SetRectEmpty();
	oldClipBoxRect.SetRectEmpty(); 

	if(!_memoryDC)
		_memoryDC = new CMemoryDC(pDC);

	_memoryDC->GetClipBox(&oldClipBoxRect);
	GetClientRect(&clipBoxRect);

	if(oldClipBoxRect != clipBoxRect)
	{
		SAFE_DELETE(_memoryDC);
		_memoryDC = new CMemoryDC(pDC, &clipBoxRect);
	}

	_memoryDC->NextFrame(pDC);
}
void COpenVideoFileView::OnDraw(CDC* pDC)	// COpenVideoFileView drawing
{
	COpenVideoFileDoc* pDoc = GetDocument();
	ASSERT_VALID(pDoc);
	if(!pDoc || !pDoc->_videoManager || !pDoc->_videoManager->IsVideoStraemOpen())
		return;

	CSize imageSize;
	UCHAR *data = NULL;
	BITMAPINFO *header = NULL;
	Bitmap *imageToShow = NULL;

	DrawNextFrameDC(pDC);

	if(!_memoryDC)
		return;

	Graphics graphDevice(_memoryDC->GetSafeHdc());
	graphDevice.Clear(Color(255,255,255));

	imageSize = pDoc->_videoManager->GetColorImageSize();
	header    = pDoc->_videoManager->GetColorHeader();
	data	  = pDoc->_videoManager->GetColorData();

	imageToShow = Bitmap::FromBITMAPINFO(header, data);
	graphDevice.DrawImage(imageToShow, 10, 10, imageSize.cx, imageSize.cy);

	_memoryDC->Display();

	graphDevice.ReleaseHDC(_memoryDC->GetSafeHdc());
}
/********************************************************************************/
#ifdef _DEBUG	// COpenVideoFileView diagnostics
void COpenVideoFileView::AssertValid() const { CView::AssertValid(); }
void COpenVideoFileView::Dump(CDumpContext& dc) const { CView::Dump(dc); }
COpenVideoFileDoc* COpenVideoFileView::GetDocument() const // non-debug version is inline
{
	ASSERT(m_pDocument->IsKindOf(RUNTIME_CLASS(COpenVideoFileDoc)));
	return (COpenVideoFileDoc*)m_pDocument;
}
#endif //_DEBUG
/********************************************************************************/
void COpenVideoFileView::OnInitialUpdate()	// COpenVideoFileView message handlers
{
	CView::OnInitialUpdate();

	COpenVideoFileDoc* pDoc = GetDocument();
	if(!pDoc)
		return;

	pDoc->SetViewWnd(this);
}
/********************************************************************************/